"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.extractStatements = void 0;
var _antlr4Browser = _interopRequireDefault(require("@neo4j-cypher/antlr4-browser"));
var _editorSupport = require("@neo4j-cypher/editor-support");
var _antlr4Simple = require("@neo4j-cypher/antlr4-simple");
var _ReferencesListener = require("./ReferencesListener.simple");
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

const extractStatements = input => {
  const referencesListener = new _ReferencesListener.ReferencesListener();
  const errorListener = new _editorSupport.ErrorListener();
  const chars = new _antlr4Browser.default.InputStream(input);
  const lexer = new _antlr4Simple.CypherLexer(chars);
  lexer.removeErrorListeners();
  lexer.addErrorListener(errorListener);
  const tokens = new _antlr4Browser.default.CommonTokenStream(lexer);
  const parser = new _antlr4Simple.CypherParser(tokens);
  parser.buildParseTrees = true;
  parser.removeErrorListeners();
  parser.addErrorListener(errorListener);
  parser.addParseListener(referencesListener);
  const parseTree = parser.cypher();
  const {
    queries,
    indexes
  } = referencesListener;
  const referencesProviders = new Map();
  _editorSupport.CypherTypes.SYMBOLIC_CONTEXTS.forEach(sc => {
    referencesProviders.set(sc, new _editorSupport.ReferencesProvider(queries, indexes.get(sc)));
  });
  return {
    parseTree,
    referencesListener,
    errorListener,
    referencesProviders
  };
};
exports.extractStatements = extractStatements;